@@ -1,4 +1,4 @@
-from src.drpython.telegram import notify_telegram
+from drpython.telegram import notify_telegram
 import os
 from dotenv import load_dotenv
 
@@ -9,7 +9,7 @@ token = os.getenv("DRPYTHON_TELEGRAM_TOKEN")
 chat_id = os.getenv("DRPYTHON_CHAT_ID")
 print(token, chat_id)
 success = notify_telegram(
-    message="Test from drpython – it works!",
+    message="Test from Dr. Python – it works!",
     token=token,  # ← real token
     chat_id=chat_id,  # ← real chat id
     parse_mode="HTML",
